@@ -198,9 +198,9 @@ gpm_profile_get_data_time_percent (GpmProfile *profile, gboolean discharge)
 		value_accuracy = gpm_array_float_get (array_accuracy, i);
 		/* only set points that are not zero */
 		if (value_data == 0) {
-			gpm_array_set (profile->priv->present_array_data, i, i, value_data, GPM_COLOUR_BLUE);
-		} else if (value_accuracy == 0) {
 			gpm_array_set (profile->priv->present_array_data, i, i, value_data, GPM_COLOUR_DARK_GREY);
+		} else if (value_accuracy == 0) {
+			gpm_array_set (profile->priv->present_array_data, i, i, value_data, GPM_COLOUR_BLUE);
 		} else if (value_data > 0) {
 			gpm_array_set (profile->priv->present_array_data, i, i, value_data, GPM_COLOUR_RED);
 		}
@@ -254,12 +254,12 @@ gpm_profile_get_data_accuracy_percent (GpmProfile *profile, gboolean discharge)
 	g_return_val_if_fail (profile != NULL, NULL);
 	g_return_val_if_fail (GPM_IS_PROFILE (profile), NULL);
 
-	if (discharge == TRUE) {
-		colour_active = GPM_COLOUR_RED;
-		colour_nonactive = GPM_COLOUR_DARK_RED;
-	} else {
+	if (discharge) {
 		colour_active = GPM_COLOUR_BLUE;
 		colour_nonactive = GPM_COLOUR_DARK_BLUE;
+	} else {
+		colour_active = GPM_COLOUR_RED;
+		colour_nonactive = GPM_COLOUR_DARK_RED;
 	}
 
 	/* get the correct data */
@@ -670,9 +670,8 @@ dpms_mode_changed_cb (GpmDpms    *dpms,
 gboolean
 gpm_profile_delete_data (GpmProfile *profile, gboolean discharge)
 {
-	gchar *filename;
-	gboolean ret;
-	gint retval = TRUE;
+	gchar *filename = NULL;
+	gboolean ret = FALSE;
 
 	g_return_val_if_fail (profile != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_PROFILE (profile), FALSE);
@@ -680,24 +679,24 @@ gpm_profile_delete_data (GpmProfile *profile, gboolean discharge)
 	/* check we have a profile loaded */
 	if (profile->priv->config_id == NULL) {
 		gpm_warning ("no config id set!");
-		return FALSE;
+		goto out;
 	}
 
 	/* create filename and check is exists */
 	filename = gpm_profile_get_data_file (profile, discharge);
 	if (g_file_test (filename, G_FILE_TEST_EXISTS) == FALSE) {
-		g_free (filename);
 		/* seems insane, but we need this for the test suite */
-		return TRUE;
+		ret = TRUE;
+		goto out;
 	}
 
 	/* try to delete file */
-	retval = g_unlink (filename);
-	if (retval != 0) {
+	if (g_unlink (filename) != 0) {
 		gpm_warning ("could not delete '%s'", filename);
-		ret = FALSE;
+		goto out;
 	}
-
+	ret = TRUE;
+out:
 	g_free (filename);
 	return ret;
 }
